==> side_menu_v5.1.1.tar.gz: side_menu/l10n/zh_CN.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "自定义菜单",
    "Enable the custom menu": "启用自定义菜单",
    "No": "取消",
    "Yes": "确定",
    "Menu": "菜单",
    "Use the shortcut Ctrl+o to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "使用快捷键 Ctrl+o 打开或隐藏侧边栏菜单。使用<span class=\"keyboard-key\">tab<\/span> 来导航。",
    "Top menu": "顶部菜单",
    "Apps that not must be moved in the side menu": "禁止在侧边栏菜单移动的应用",
    "If there is no selection then the global configuration is applied.": "如果没有选择，则应用全局配置。",
    "Experimental": "实验性",
    "Save": "保存",
    "You like this app and you want to support me?": "喜欢本应用并支持我一下？",
    "Buy me a coffee ☕": "赏一杯咖啡 ☕ 给我",
    "Hidden": "隐藏",
    "Small": "小型",
    "Normal": "标准",
    "Big": "大型",
    "Colors": "颜色",
    "Background color": "背景颜色",
    "Background color of current app": "当前应用的背景色",
    "Text color": "文本颜色",
    "Loader": "菜单指示器",
    "Icon": "图标",
    "Same color": "相同颜色",
    "Opposite color": "相反颜色",
    "Transparent": "透明",
    "Opaque": "不透明",
    "Opener": "容器",
    "Default": "默认",
    "Default (dark)": "默认(深色)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (深色)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (深色)",
    "Before the logo": "在徽标之前",
    "After the logo": "在徽标之后",
    "Position": "位置",
    "Show only the opener (hidden logo)": "只显示容器（隐藏徽标）",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "如果没有应用程序（例如：公共页面），则不要显示侧边栏菜单和容器。",
    "Panel": "面板",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "鼠标悬停时打开菜单 (触摸屏时将自动禁用)",
    "Display the big menu": "显示大型菜单",
    "Display the logo": "显示徽标",
    "Icons and texts": "图标和文本",
    "Loader enabled": "菜单指示器已启用",
    "Tips": "技巧",
    "Always displayed": "始终显示",
    "This is the automatic behavior when the menu is always displayed.": "这是菜单始终显示时的自动行为。",
    "Not compatible with touch screens.": "与触摸屏不兼容。",
    "Big menu": "大型菜单",
    "Live preview": "实时预览",
    "Open apps in new tab": "在新标签页中打开应用",
    "Use the global setting": "使用全局设置",
    "Use my selection": "使用自定义设置",
    "Show and hide the list of applications": "显示和隐藏应用程序列表",
    "Use the avatar instead of the logo": "使用头像代替徽标",
    "You do not have permission to change the settings.": "您没有更改设置的权限。",
    "Force this configuration to users": "强制用户使用此配置",
    "Export the configuration": "导出配置",
    "Purge the cache": "清除缓存",
    "Show the link to settings": "显示设置链接",
    "The menu is enabled by default for users": "默认情况下为用户启用菜单",
    "Except when the configuration is forced.": "除非强制配置。",
    "Apps that should not be displayed in the menu": "禁止在菜单中显示的应用",
    "This feature is only compatible with the <code>big menu<\/code> display.": "此功能只和<code>大型菜单<\/code>兼容。",
    "The logo is a link to the default app": "logo链接到默认应用",
    "Others": "其他",
    "Categories": "类别",
    "Customize sorting": "自定义排序",
    "Order by": "排序方式",
    "Name": "名称",
    "Customed": "自定义",
    "Show and hide the list of categories": "显示或隐藏类别列表",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "启用深色主题时使用此参数。",
    "Dark mode colors": "深色模式颜色",
    "With categories": "按类别",
    "Custom categories": "自定义类别",
    "Customize application categories": "自定义应用程序类别",
    "Reset to default": "重置为默认设置",
    "Hidden icon": "隐藏图标",
    "Small icon": "小图标",
    "Normal icon": "正常图标",
    "Big icon": "大图标",
    "Hidden text": "隐藏文本",
    "Small text": "小文本",
    "Normal text": "普通文本",
    "Big text": "大文本",
    "Applications": "Applications",
    "Applications kept in the top menu": "Applications kept in the top menu",
    "Applications kept in the top menu but also shown in side menu": "Applications kept in the top menu but also shown in side menu",
    "These applications must be selected in the previous option.": "These applications must be selected in the previous option.",
    "Hide labels on mouse over": "Hide labels on mouse over",
    "Except the hovered app": "Except the hovered app",
    "Search": "Search",
    "Toggle menu": "Toggle menu",
    "Open the documentation": "Open the documentation",
    "Ask the developer": "Ask the developer",
    "New request": "New request",
    "Report a bug": "Report a bug",
    "Show the configuration": "Show the configuration",
    "Configuration:": "Configuration:",
    "Done!": "Done!",
    "Copy": "Copy",
    "Need help": "Need help",
    "I would like a new feature": "I would like a new feature",
    "Something went wrong": "Something went wrong",
    "Select apps": "Select apps",
    "Sort": "Sort",
    "Customize": "Customize",
    "Custom": "Custom",
    "Close": "Close"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> side_menu_v5.1.3.tar.gz: side_menu/l10n/zh_CN.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "自定义菜单",
    "Enable the custom menu": "启用自定义菜单",
    "No": "否",
    "Yes": "是",
    "Menu": "菜单",
    "Use the shortcut Ctrl+o to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "使用快捷键 Ctrl+o 打开或隐藏侧边栏菜单。使用 <span class=\"keyboard-key\">Tab<\/span> 键来导航。",
    "Top menu": "顶部菜单",
    "Apps that not must be moved in the side menu": "禁止在侧边栏菜单移动的应用",
    "If there is no selection then the global configuration is applied.": "如果没有选择，则应用全局配置。",
    "Experimental": "实验性",
    "Save": "保存",
    "You like this app and you want to support me?": "喜欢本应用并支持我一下？",
    "Buy me a coffee ☕": "赏一杯咖啡 ☕ 给我",
    "Hidden": "隐藏",
    "Small": "小型",
    "Normal": "标准",
    "Big": "大型",
    "Colors": "颜色",
    "Background color": "背景颜色",
    "Background color of current app": "当前应用的背景色",
    "Text color": "文本颜色",
    "Loader": "菜单指示器",
    "Icon": "图标",
    "Same color": "相同颜色",
    "Opposite color": "相反颜色",
    "Transparent": "透明",
    "Opaque": "不透明",
    "Opener": "触发器",
    "Default": "默认",
    "Default (dark)": "默认(深色)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (深色)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (深色)",
    "Before the logo": "在徽标之前",
    "After the logo": "在徽标之后",
    "Position": "位置",
    "Show only the opener (hidden logo)": "仅显示触发器（隐藏徽标）",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "如果没有应用程序（例如：公共页面），则不要显示侧边栏菜单和触发器。",
    "Panel": "面板",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "‌当鼠标悬停在触发器上时打开菜单（在触摸屏上自动禁用）",
    "Display the big menu": "显示大型菜单",
    "Display the logo": "显示徽标",
    "Icons and texts": "图标和文本",
    "Loader enabled": "菜单指示器已启用",
    "Tips": "技巧",
    "Always displayed": "始终显示",
    "This is the automatic behavior when the menu is always displayed.": "这是菜单始终显示时的自动行为。",
    "Not compatible with touch screens.": "与触摸屏不兼容。",
    "Big menu": "大型菜单",
    "Live preview": "实时预览",
    "Open apps in new tab": "在新标签页中打开应用",
    "Use the global setting": "使用全局设置",
    "Use my selection": "使用自定义设置",
    "Show and hide the list of applications": "显示和隐藏应用程序列表",
    "Use the avatar instead of the logo": "使用头像代替徽标",
    "You do not have permission to change the settings.": "您没有更改设置的权限。",
    "Force this configuration to users": "强制用户使用此配置",
    "Export the configuration": "导出配置",
    "Purge the cache": "清除缓存",
    "Show the link to settings": "显示设置链接",
    "The menu is enabled by default for users": "默认情况下为用户启用菜单",
    "Except when the configuration is forced.": "除非强制配置。",
    "Apps that should not be displayed in the menu": "禁止在菜单中显示的应用",
    "This feature is only compatible with the <code>big menu<\/code> display.": "此功能只和<code>大型菜单<\/code>兼容。",
    "The logo is a link to the default app": "徽标链接到默认应用",
    "Others": "其他",
    "Categories": "类别",
    "Customize sorting": "自定义排序",
    "Order by": "排序方式",
    "Name": "名称",
    "Customed": "自定义",
    "Show and hide the list of categories": "显示或隐藏类别列表",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "启用深色主题时使用此参数。",
    "Dark mode colors": "深色模式颜色",
    "With categories": "按类别",
    "Custom categories": "自定义类别",
    "Customize application categories": "自定义应用程序类别",
    "Reset to default": "重置为默认设置",
    "Hidden icon": "隐藏图标",
    "Small icon": "小图标",
    "Normal icon": "正常图标",
    "Big icon": "大图标",
    "Hidden text": "隐藏文本",
    "Small text": "小文本",
    "Normal text": "普通文本",
    "Big text": "大文本",
    "Applications": "应用程序",
    "Applications kept in the top menu": "应用程序保留在顶部菜单中",
    "Applications kept in the top menu but also shown in side menu": "应用程序保留在顶部菜单中，但也显示在侧边栏菜单中",
    "These applications must be selected in the previous option.": "必须在上一个选项中选择这些应用程序。",
    "Hide labels on mouse over": "鼠标悬停时隐藏标签",
    "Except the hovered app": "除了悬停的应用",
    "Search": "搜索",
    "Toggle menu": "切换菜单",
    "Open the documentation": "打开文档",
    "Ask the developer": "询问开发者",
    "New request": "新请求",
    "Report a bug": "报告错误",
    "Show the configuration": "显示配置",
    "Configuration:": "配置：",
    "Done!": "完成！",
    "Copy": "复制",
    "Need help": "需要帮助",
    "I would like a new feature": "我想要一个新功能",
    "Something went wrong": "出了点问题",
    "Select apps": "选择应用",
    "Sort": "排序",
    "Customize": "自定义",
    "Custom": "自定义",
    "Close": "关闭"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
